<?php

namespace Drupal\mapkit\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\mapkit\Autocomplete\AutocompleteManagerInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Form for configuring mapkit settings and defaults.
 */
class MapkitSettingsForm extends ConfigFormBase {

  /**
   * The Mapkit autocomplete manager service.
   *
   * @var \Drupal\mapkit\Autocomplete\AutocompleteManagerInterface
   */
  protected AutocompleteManagerInterface $autocompleteManager;

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container): static {
    /** @var static */
    return parent::create($container)
      ->setMapkitAutocompleteManager($container->get('strategy.manager.mapkit.autocomplete'));
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId(): string {
    return '';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames(): array {
    return [
      'mapkit.settings',
    ];
  }

  /**
   * Set the mapkit autocomplete manager.
   *
   * @param \Drupal\mapkit\Autocomplete\AutocompleteManagerInterface $autocompleteManager
   *   The Mapkit autocomplete strategy manager.
   *
   * @return self
   *   The config form for method chaining.
   */
  public function setMapkitAutocompleteManager(AutocompleteManagerInterface $autocompleteManager): self {
    $this->autocompleteManager = $autocompleteManager;
    return $this;
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state): array {
    $form = parent::buildForm($form, $form_state);
    $settings = $this->config('mapkit.settings');

    $acHandlers = $this->autocompleteManager->getAutocompleteOptions();
    if ($acHandlers) {
      $form['autocompleteHandler'] = [
        '#type' => 'select',
        '#title' => $this->t('Default autocomplete handler'),
        '#options' => $acHandlers,
        '#default_value' => $settings->get('autocompleteHandler') ?? NULL,
      ];
    }
    else {
      // @todo prompt user to install autocomplete providers.
    }

    $form['bounds'] = [
      '#type' => 'latlng_bound',
      '#title' => $this->t('Default map bounds'),
      '#default_value' => $settings->get('bounds') ?? NULL,
    ];

    return $form;
  }

}
